@@ -1,26 +1,38 @@
-#**********************************************************************************************************************************
-#**********************************************************************************************************************************
-#
-#  ParaMonte: plain powerful parallel Monte Carlo library.
-#
-#  Copyright (C) 2012-present, The Computational Data Science Lab
-#
-#  This file is part of ParaMonte library.
-#
-#  ParaMonte is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU Lesser General Public License as published by
-#  the Free Software Foundation, version 3 of the License.
-#
-#  ParaMonte is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU Lesser General Public License for more details.
-#
-#  You should have received a copy of the GNU Lesser General Public License
-#  along with ParaMonte.  If not, see <https://www.gnu.org/licenses/>.
-#
-#**********************************************************************************************************************************
-#**********************************************************************************************************************************
+####################################################################################################################################
+####################################################################################################################################
+####
+####   ParaMonte: plain powerful parallel Monte Carlo library.
+####
+####   Copyright (C) 2012-present, The Computational Data Science Lab
+####
+####   This file is part of the ParaMonte library.
+####
+####   ParaMonte is free software: you can redistribute it and/or modify it
+####   under the terms of the GNU Lesser General Public License as published
+####   by the Free Software Foundation, version 3 of the License.
+####
+####   ParaMonte is distributed in the hope that it will be useful,
+####   but WITHOUT ANY WARRANTY; without even the implied warranty of
+####   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+####   GNU Lesser General Public License for more details.
+####
+####   You should have received a copy of the GNU Lesser General Public License
+####   along with the ParaMonte library. If not, see,
+####
+####       https://github.com/cdslaborg/paramonte/blob/master/LICENSE
+####
+####   ACKNOWLEDGMENT
+####
+####   As per the ParaMonte library license agreement terms,
+####   if you use any parts of this library for any purposes,
+####   we ask you to acknowledge the use of the ParaMonte library
+####   in your work (education/research/industry/development/...)
+####   by citing the ParaMonte library as described on this page:
+####
+####       https://github.com/cdslaborg/paramonte/blob/master/ACKNOWLEDGMENT.md
+####
+####################################################################################################################################
+####################################################################################################################################
 
 import numpy as _np
 import typing as _tp
@@ -42,89 +54,135 @@ from _visutils import ParaMonteFigure
 
 class HeatMapPlot():
     """
-    This is the HeatMapPlot class for generating instances 
-    of histogram figures based on seaborn library's heatmap().
-    Usage: first generate an object of this class by optionally 
-    passing the following parameters described below. Then call 
-    the plot() method.
 
-    Parameters
-    ----------
-        dataFrame
-            a numpy 2D-array or a pandas dataframe containing the data to plot.
-        columns
-            optional argument that determines the columns of dataframe to be visualized. 
-            It can have three forms:
-                1. a list of column indices in the input dataFrame.
-                2. a list of column names in dataFrame.columns.
-                3. a range(start,stop,step), representing the column indices in dataFrame.
-            Examples:
-                1. columns = [0,1,4,3]
-                2. columns = ["SampleLogFunc","SampleVariable1"]
-                3. columns = range(17,7,-2)
-            If not provided, the default behavior includes all columns of the dataframe.
-        rows
-            optional argument that determines the rows of dataframe to be visualized. 
-            It can be either:
-                1. a range(start,stop,step), or, 
-                2. a list of row indices in dataFrame.index.
-            Examples:
-                1. rows = range(17,7,-2)
-                2. rows = [i for i in range(7,17)]
-            If not provided, the default behavior includes all rows of the dataframe.
-        set_kws
-            optional dictionary of keyword arguments to be passed to seaborn's 
-            set() function. For example: 
-                set_kws = {"style":"darkgrid"}
-            if set to None, then no call to set() function will be made.
-        figure_kws
-            optional dictionary of keyword arguments to be passed to matplotlib's 
-            figure() function. For example: 
-                figure_kws = {"facecolor":"w","dpi":150}
-        legend_kws
-            optional dictionary of keyword arguments to be passed to matplotlib's 
-            legend() function. If it is not provided, the legend will be added
-            to the plot. If it is set to {}, then the legend will be added 
-            to the plot and automatically adjusted. For example: 
-                legend_kws = {"labels":["Variable1","Variable2"]}
-        heatmap_kws
-            optional dictionary of keyword arguments to be passed to seaborn's 
-            heatmap() function. For example: 
-                heatmap_kws = {"square": True}
-        xticklabels_kws
-            optional dictionary of keyword arguments to be passed to matplotlib's 
-            set_xticklabels() method of the Axes object of the plot. For example: 
-                xticklabels_kws = {"verticalalignment": "baseline"}
-        yticklabels_kws
-            optional dictionary of keyword arguments to be passed to matplotlib's 
-            set_yticklabels() method of the Axes object of the plot. For example: 
-                yticklabels_kws = {"verticalalignment": "baseline"}
-        annotPrecision
-            optional integer which determines the precision of the output numbers
-            when heatmap annotation is requested via 'annot' key in heatmap_kws.
-        outputFile
-            optional string representing the name of the output file in which 
-            the figure will be saved. If not provided, no output file will be generated.
-            and the corresponding attribute of object will be None.
+    .. py:class:: HeatMapPlot
 
-    Attributes
-    ----------
-        All of the parameters described above, except dataFrame.
-            a reference to the dataFrame will be implicitly stored in the object.
-        currentFig
-            an object of class ParaMonteFigure which is initially None, but upon 
-            making a plot, is populated with attributes representing all outputs 
-            from matplotlib/seaborn function calls, with the following attributes:
-                figure
-                    the output of matplotlib's figure() function.
-                axes
-                    the output of seaborns's heatmap() function.
+    This is the HeatMapPlot class for generating instances
+    of histogram figures based on seaborn library's ``heatmap()``.
 
-    Returns
-    -------
-        HeatMapPlot
+        **Usage**
 
-    ----------------------------------------------------------------------
+            First generate an object of this class by optionally
+            passing the following parameters described below. Then call
+            the ``plot()`` method.
+
+        **Parameters**
+
+            dataFrame
+                a numpy 2D-array or a pandas dataframe containing the data to plot.
+
+            columns
+                optional argument that determines the columns of dataframe to be visualized.
+                It can have three forms:
+
+                    1. a list of column indices in the input dataFrame.
+                    2. a list of column names in dataFrame.columns.
+                    3. a ``range(start,stop,step)``, representing the column indices in dataFrame.
+
+                Examples:
+
+                    1. ``columns = [0,1,4,3]``
+                    2. ``columns = ["SampleLogFunc","SampleVariable1"]``
+                    3. ``columns = range(17,7,-2)``
+
+                If not provided, the default behavior includes all columns of the dataframe.
+
+            rows
+                optional argument that determines the rows of dataframe to be visualized.
+                It can be either:
+                    1. a ``range(start,stop,step)``, or,
+                    2. a list of row indices in dataFrame.index.
+
+                Examples:
+
+                    1. ``rows = range(17,7,-2)``
+                    2. ``rows = [i for i in range(7,17)]``
+
+                If not provided, the default behavior includes all rows of the dataframe.
+
+            set_kws
+                optional dictionary of keyword arguments to be passed to seaborn's
+                ``set()`` function. For example:
+
+                .. code-block:: python
+
+                    set_kws = {"style":"darkgrid"}
+
+                if set to ``None``, then no call to ``set()`` function will be made.
+
+            figure_kws
+                optional dictionary of keyword arguments to be passed to matplotlib's
+                ``figure()`` function. For example:
+
+                .. code-block:: python
+
+                    figure_kws = {"facecolor":"w","dpi":150}
+
+            legend_kws
+                optional dictionary of keyword arguments to be passed to matplotlib's
+                ``legend()`` function. If it is not provided, the legend will be added
+                to the plot. If it is set to ``{}``, then the legend will be added
+                to the plot and automatically adjusted. For example:
+
+                .. code-block:: python
+
+                    legend_kws = {"labels":["Variable1","Variable2"]}
+
+            heatmap_kws
+                optional dictionary of keyword arguments to be passed to seaborn's
+                ``heatmap()`` function. For example:
+
+                .. code-block:: python
+
+                    heatmap_kws = {"square": True}
+
+            xticklabels_kws
+                optional dictionary of keyword arguments to be passed to matplotlib's
+                ``set_xticklabels()`` method of the Axes object of the plot. For example:
+
+                .. code-block:: python
+
+                    xticklabels_kws = {"verticalalignment": "baseline"}
+
+            yticklabels_kws
+                optional dictionary of keyword arguments to be passed to matplotlib's
+                ``set_yticklabels()`` method of the Axes object of the plot. For example:
+
+                .. code-block:: python
+
+                    yticklabels_kws = {"verticalalignment": "baseline"}
+
+            annotPrecision
+                optional integer which determines the precision of the output numbers
+                when heatmap annotation is requested via ``'annot'`` key in heatmap_kws.
+
+            outputFile
+                optional string representing the name of the output file in which
+                the figure will be saved. If not provided, no output file will be generated.
+                and the corresponding attribute of object will be ``None``.
+
+        **Attributes**
+
+            All of the parameters described above, except dataFrame.
+                a reference to the dataFrame will be implicitly stored in the object.
+
+            currentFig
+                an object of class ParaMonteFigure which is initially None, but upon
+                making a plot, is populated with attributes representing all outputs
+                from matplotlib/seaborn function calls, with the following attributes:
+
+                    figure
+                        the output of matplotlib's ``figure()`` function.
+
+                    axes
+                        the output of seaborns's ``heatmap()`` function.
+
+        **Returns**
+
+            self
+                an object of class ``HeatMapPlot``.
+
+    ---------------------------------------------------------------------------
     """
 
     def __init__( self
@@ -170,21 +228,24 @@ class HeatMapPlot():
                 , **kwargs
                 ):
         """
-        calls the plot() method of the current instance of the class.
 
-        Parameters
-        ----------
-            reself
-                logical variable. If True, an instance of the object 
-                will be returned upon exit to the calling routine.
-                The default value is False.
-            also, any attributes of the current instance of the class.
+        .. py:method:: __call__(self, reself = False, **kwargs)
 
-        Returns
-        -------
-            the object self if reself = True otherwise, None.
-            However, this method causes side-effects by manipulating 
-            the existing attributes of the object.
+        calls the ``plot()`` method of the current instance of the class.
+
+            **Parameters**
+
+                reself
+                    logical variable. If True, an instance of the object
+                    will be returned upon exit to the calling routine.
+                    The default value is ``False``.
+                also, any attributes of the current instance of the class.
+
+            **Returns**
+
+                the object self if ``reself = True`` otherwise, None.
+                However, this method causes side-effects by manipulating
+                the existing attributes of the object.
 
         """
 
@@ -205,17 +266,20 @@ class HeatMapPlot():
 
     def plot(self):
         """
-        Generate a heatmap of the requested columns from the selected columns of 
+
+        .. py:method:: plot(self)
+
+        Generate a heatmap of the requested columns from the selected columns of
         object's dataframe.
 
-        Parameters
-        ----------
-            None
+            **Parameters**
 
-        Returns
-        -------
-            None. However, this method causes side-effects by manipulating 
-            the existing attributes of the object.
+                None
+
+            **Returns**
+
+                None. However, this method causes side-effects by manipulating
+                the existing attributes of the object.
 
         """
 
@@ -292,18 +356,15 @@ class HeatMapPlot():
 
         # check data type
 
-        noDataPassed = False
+        noDataPassed = ""
         if self._dfref is None:
-            noDataPassed = True
-            fatalmsg = "It appears that no data has been passed for plotting.\n"
+            noDataPassed = "It appears that no data has been passed for plotting.\n"
         elif not isinstance(self._dfref,_wref.ref):
-            noDataPassed = True
-            fatalmsg = "It appears that you have messed with the\ninternal representation of data in the object.\n"
+            noDataPassed = "It appears that you have messed with the\ninternal representation of data in the object.\n"
         elif not isinstance(self._dfref(),_pd.DataFrame):
-            noDataPassed = True
-            fatalmsg = ""
+            noDataPassed = "The input data is not a pandas' dataframe.\n"
         if noDataPassed:
-            raise Exception ( fatalmsg
+            raise Exception ( noDataPassed
                             + "The input data must be a pandas' dataframe.\n"
                             + "Please pass a dataFrame to the constructor or at\n"
                             + "the time of calling the object (which is callable with\n"
@@ -361,7 +422,7 @@ class HeatMapPlot():
 
         _plt.tight_layout()
 
-        if figEnabled: 
+        if figEnabled:
 
             # default figure size
 
@@ -383,7 +444,7 @@ class HeatMapPlot():
 
             self.currentFig.figure.set_size_inches(figWidth,figHeight)
 
-        if self.outputFile is not None: 
+        if self.outputFile is not None:
             self.currentFig.figure.savefig  ( self.outputFile
                                             , bbox_inches = 'tight'
                                             , pad_inches = 0.0
